% Auto-generated chapter 27 for muslim
% Hadiths in this chapter: 88

\hadithdefcmd{muslim}{4254}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، ح وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ، عَبْدِ اللَّهِ عَنْ أَبِيهِ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ يَنْهَاكُمْ أَنْ تَحْلِفُوا بِآبَائِكُمْ ‏"‏ ‏.‏ قَالَ عُمَرُ فَوَاللَّهِ مَا حَلَفْتُ بِهَا مُنْذُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْهَا ذَاكِرًا وَلاَ آثِرًا ‏.‏\hadithno{4254}\hadithtrans{Umar b. al-Khattib reported Allah's Messenger (ﷺ) as saying:Allah, the Great and Majestic, forbids you to swear by your fathers. Umar said: By Allah. I have never sworn (by my father) since I heard Allah's Messenger (ﷺ) forbidding it mentioning them" on my behalf" nor on behalf of someone else}}
\hadithdefcmd{muslim}{4255}{وَحَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ، خَالِدٍ ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّ فِي حَدِيثِ عُقَيْلٍ مَا حَلَفْتُ بِهَا مُنْذُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنْهَا وَلاَ تَكَلَّمْتُ بِهَا ‏.‏ وَلَمْ يَقُلْ ذَاكِرًا وَلاَ آثِرًا ‏.‏\hadithno{4255}\hadithtrans{This hadith has been transmitted on the authority of Zuhri except that in the hadith narrated on the authority of Uqail the words are:" I did not take oath by (anyone else except Allah) since I heard Allah's Messenger forbidding it. nor did I speak in such terms, and the narrator did not say," on my own behalf or on behalf of someone else}}
\hadithdefcmd{muslim}{4256}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالُوا حَدَّثَنَا سُفْيَانُ، بْنُ عُيَيْنَةَ عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ سَمِعَ النَّبِيُّ صلى الله عليه وسلم عُمَرَ وَهُوَ يَحْلِفُ بِأَبِيهِ ‏.‏ بِمِثْلِ رِوَايَةِ يُونُسَ وَمَعْمَرٍ ‏.‏\hadithno{4256}\hadithtrans{Salim reported on the authority of his father that Allah's Apostle (ﷺ) heard 'Umar while he was taking oath by his father. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{4257}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ أَدْرَكَ عُمَرَ بْنَ الْخَطَّابِ فِي رَكْبٍ وَعُمَرُ يَحْلِفُ بِأَبِيهِ فَنَادَاهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ إِنَّ اللَّهَ عَزَّ وَجَلَّ يَنْهَاكُمْ أَنْ تَحْلِفُوا بِآبَائِكُمْ فَمَنْ كَانَ حَالِفًا فَلْيَحْلِفْ بِاللَّهِ أَوْ لِيَصْمُتْ ‏"‏\hadithno{4257}\hadithtrans{Abdullah (b. Umar) reported that Allah's Messenger (ﷺ) found, Umar b. al-Khattab amongst the riders and he was taking oath by his father Allah's Messenger (ﷺ) called them (saying) ; Our Allah, the Exated and Majestic, has forbidden you that you take oath by your father. He who bag to take an oath, he must take it by Allah or keep quiet}}
\hadithdefcmd{muslim}{4258}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنِي بِشْرُ بْنُ هِلاَلٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ بْنِ كَثِيرٍ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، ح وَحَدَّثَنَا ابْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، وَابْنُ أَبِي ذِئْبٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ، رَافِعٍ عَنْ عَبْدِ الرَّزَّاقِ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي عَبْدُ الْكَرِيمِ، ‏.‏ كُلُّ هَؤُلاَءِ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، بِمِثْلِ هَذِهِ الْقِصَّةِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{4258}\hadithtrans{This hadith is narrated on the authority of Ibn Umar through another chain of transmitters}}
\hadithdefcmd{muslim}{4259}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَيَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالَ يَحْيَى بْنُ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّهُ سَمِعَ ابْنَ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ كَانَ حَالِفًا فَلاَ يَحْلِفْ إِلاَّ بِاللَّهِ ‏"‏ ‏.‏ وَكَانَتْ قُرَيْشٌ تَحْلِفُ بِآبَائِهَا فَقَالَ ‏"‏ لاَ تَحْلِفُوا بِآبَائِكُمْ ‏"‏ ‏.‏\hadithno{4259}\hadithtrans{Ibn 'Umar heard Allah's Messenger (ﷺ) as saying:He who has to take an oath, he must not take oath but by Allah. The Quraish used to take oath by their fathers. So he (the Holy Prophet) said: Do not take oath by your fathers}}
\hadithdefcmd{muslim}{4260}{حَدَّثَنِي أَبُو الطَّاهِرِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، ح وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ مِنْكُمْ فَقَالَ فِي حَلِفِهِ بِاللاَّتِ ‏.‏ فَلْيَقُلْ لاَ إِلَهَ إِلاَّ اللَّهُ ‏.‏ وَمَنْ قَالَ لِصَاحِبِهِ تَعَالَ أُقَامِرْكَ ‏.‏ فَلْيَتَصَدَّقْ ‏"‏ ‏.‏\hadithno{4260}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:He who takes an oath in the course of which he says: By Lat (and al-'Uzza), he should say: There is no god but Allah; and that if anyone says to his friend:" Come and I will gamble with you," he should pay sadaqa}}
\hadithdefcmd{muslim}{4261}{وَحَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، ح وَحَدَّثَنَا إِسْحَاقُ، بْنُ إِبْرَاهِيمَ وَعَبْدُ بْنُ حُمَيْدٍ قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ وَحَدِيثُ مَعْمَرٍ مِثْلُ حَدِيثِ يُونُسَ غَيْرَ أَنَّهُ قَالَ ‏"‏ فَلْيَتَصَدَّقْ بِشَىْءٍ ‏"‏ ‏.‏ وَفِي حَدِيثِ الأَوْزَاعِيِّ ‏"‏ مَنْ حَلَفَ بِاللاَّتِ وَالْعُزَّى ‏"‏ ‏.‏ قَالَ أَبُو الْحُسَيْنِ مُسْلِمٌ هَذَا الْحَرْفُ - يَعْنِي قَوْلَهُ تَعَالَ أُقَامِرْكَ ‏.‏ فَلْيَتَصَدَّقْ - لاَ يَرْوِيهِ أَحَدٌ غَيْرُ الزُّهْرِيِّ قَالَ وَلِلزُّهْرِيِّ نَحْوٌ مِنْ تِسْعِينَ حَدِيثًا يَرْوِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم لاَ يُشَارِكُهُ فِيهِ أَحَدٌ بِأَسَانِيدَ جِيَادٍ ‏.‏\hadithno{4261}\hadithtrans{This hadith has been narrated on the authority of Zuhri}}
\hadithdefcmd{muslim}{4262}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ هِشَامٍ، عَنِ الْحَسَنِ، عَنْ عَبْدِ، الرَّحْمَنِ بْنِ سَمُرَةَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَحْلِفُوا بِالطَّوَاغِي وَلاَ بِآبَائِكُمْ ‏"‏ ‏.‏\hadithno{4262}\hadithtrans{Abd al-Rahman b. Samura reported Allah's Messenger (ﷺ) as saying:Do not swear by idols, nor by your fathers}}
\hadithdefcmd{muslim}{4263}{حَدَّثَنَا خَلَفُ بْنُ هِشَامٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَيَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، - وَاللَّفْظُ لِخَلَفٍ - قَالُوا حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ غَيْلاَنَ بْنِ جَرِيرٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، الأَشْعَرِيِّ قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فِي رَهْطٍ مِنَ الأَشْعَرِيِّينَ نَسْتَحْمِلُهُ فَقَالَ ‏"‏ وَاللَّهِ لاَ أَحْمِلُكُمْ وَمَا عِنْدِي مَا أَحْمِلُكُمْ عَلَيْهِ ‏"‏ ‏.‏ قَالَ فَلَبِثْنَا مَا شَاءَ اللَّهُ ثُمَّ أُتِيَ بِإِبِلٍ فَأَمَرَ لَنَا بِثَلاَثِ ذَوْدٍ غُرِّ الذُّرَى فَلَمَّا انْطَلَقْنَا قُلْنَا - أَوْ قَالَ بَعْضُنَا لِبَعْضٍ - لاَ يُبَارِكُ اللَّهُ لَنَا أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم نَسْتَحْمِلُهُ فَحَلَفَ أَنْ لاَ يَحْمِلَنَا ثُمَّ حَمَلَنَا ‏.‏ فَأَتَوْهُ فَأَخْبَرُوهُ فَقَالَ ‏"‏ مَا أَنَا حَمَلْتُكُمْ وَلَكِنَّ اللَّهَ حَمَلَكُمْ وَإِنِّي وَاللَّهِ إِنْ شَاءَ اللَّهُ لاَ أَحْلِفُ عَلَى يَمِينٍ ثُمَّ أَرَى خَيْرًا مِنْهَا إِلاَّ كَفَّرْتُ عَنْ يَمِينِي وَأَتَيْتُ الَّذِي هُوَ خَيْرٌ ‏"‏ ‏.‏\hadithno{4263}\hadithtrans{Abu Musa al-Ash'ari reported:I came to Allah's Apostle (ﷺ) along with a group of Ash'arites requesting to give us a mount. He (the Holy Prophet) said: By Allah, I cannot provide you with a mount, and there is nothing with me which I should give you as a ride. He (the narrator) said: We stayed there as long as Allah willed. Then there were brought to him (to the Holy Prophet) camels. He (the Holy Prophet) then ordered to give us three white humped camels, We started and said (or some of us said to the others): Allah will not bless us. We came to Allah's Messenger (ﷺ) begging him to provide us with riding camels. He swore that he could not provide us with a mount, but later on he provided us with that. They (some of the Prophet's Companions) came and informed him about this (rankling of theirs), whereupon he said: It was not I who provided you with a mount, but Allah has provided you with that. So far as I am concerned, by Allah, if He so wills, I would not swear, but if, later on, I would see better than it, I (would break the vow) and expiate it and do that which is better}}
\hadithdefcmd{muslim}{4264}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَرَّادٍ الأَشْعَرِيُّ، وَمُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ، - وَتَقَارَبَا فِي اللَّفْظِ - قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ أَرْسَلَنِي أَصْحَابِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَسْأَلُهُ لَهُمُ الْحُمْلاَنَ إِذْ هُمْ مَعَهُ فِي جَيْشِ الْعُسْرَةِ - وَهِيَ غَزْوَةُ تَبُوكَ - فَقُلْتُ يَا نَبِيَّ اللَّهِ إِنَّ أَصْحَابِي أَرْسَلُونِي إِلَيْكَ لِتَحْمِلَهُمْ ‏.‏ فَقَالَ ‏"‏ وَاللَّهِ لاَ أَحْمِلُكُمْ عَلَى شَىْءٍ ‏"‏ ‏.‏ وَوَافَقْتُهُ وَهُوَ غَضْبَانُ وَلاَ أَشْعُرُ فَرَجَعْتُ حَزِينًا مِنْ مَنْعِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَمِنْ مَخَافَةِ أَنْ يَكُونَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَدْ وَجَدَ فِي نَفْسِهِ عَلَىَّ فَرَجَعْتُ إِلَى أَصْحَابِي فَأَخْبَرْتُهُمُ الَّذِي قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمْ أَلْبَثْ إِلاَّ سُوَيْعَةً إِذْ سَمِعْتُ بِلاَلاً يُنَادِي أَىْ عَبْدَ اللَّهِ بْنَ قَيْسٍ ‏.‏ فَأَجَبْتُهُ فَقَالَ أَجِبْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَدْعُوكَ ‏.‏ فَلَمَّا أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ خُذْ هَذَيْنِ الْقَرِينَيْنِ وَهَذَيْنِ الْقَرِينَيْنِ وَهَذَيْنِ الْقَرِينَيْنِ - لِسِتَّةِ أَبْعِرَةٍ ابْتَاعَهُنَّ حِينَئِذٍ مِنْ سَعْدٍ - فَانْطَلِقْ بِهِنَّ إِلَى أَصْحَابِكَ فَقُلْ إِنَّ اللَّهَ - أَوْ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم - يَحْمِلُكُمْ عَلَى هَؤُلاَءِ فَارْكَبُوهُنَّ ‏"‏ ‏.‏ قَالَ أَبُو مُوسَى فَانْطَلَقْتُ إِلَى أَصْحَابِي بِهِنَّ فَقُلْتُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَحْمِلُكُمْ عَلَى هَؤُلاَءِ وَلَكِنْ وَاللَّهِ لاَ أَدَعُكُمْ حَتَّى يَنْطَلِقَ مَعِي بَعْضُكُمْ إِلَى مَنْ سَمِعَ مَقَالَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم حِينَ سَأَلْتُهُ لَكُمْ وَمَنْعَهُ فِي أَوَّلِ مَرَّةٍ ثُمَّ إِعْطَاءَهُ إِيَّاىَ بَعْدَ ذَلِكَ لاَ تَظُنُّوا أَنِّي حَدَّثْتُكُمْ شَيْئًا لَمْ يَقُلْهُ ‏.‏ فَقَالُوا لِي وَاللَّهِ إِنَّكَ عِنْدَنَا لَمُصَدَّقٌ وَلَنَفْعَلَنَّ مَا أَحْبَبْتَ ‏.‏ فَانْطَلَقَ أَبُو مُوسَى بِنَفَرٍ مِنْهُمْ حَتَّى أَتَوُا الَّذِينَ سَمِعُوا قَوْلَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَمَنْعَهُ إِيَّاهُمْ ثُمَّ إِعْطَاءَهُمْ بَعْدُ فَحَدَّثُوهُمْ بِمَا حَدَّثَهُمْ بِهِ أَبُو مُوسَى سَوَاءً ‏.‏\hadithno{4264}\hadithtrans{Abu Musa reported:My friends sent me to Allah's Messenger (ﷺ) asking him to provide them with mounts as they were going along with him in jaish al-'Usrah (the army of destitutes or of meagre means or army setting out during the hard times and that is the occasion of the expedition of Tabuk) I said: Apostle of Allah, my friends have sent me to you so that you may provide them with mounts. He (the Holy Prophet) said: By Allah, I cannot provide you with anything to ride. And it so happened that he was at that time much perturbed. I little knew of it, so I came back with a heavy heart on account of the refusal of Allah's Messenger (ﷺ), and the fear that Allah's Messenger (ﷺ) might have some feelings against me. I returned to my friends and informed them about what Allah's Messenger (ﷺ) had said. I had hardly stayed for a little that I heard Bilal calling: 'Abdullah b. Qais. I responded to his call. He said: Hasten to Allah's Messenger (ﷺ), he is calling you, When I came to the Prophet (ﷺ) he said: Take this pair, this pair, and this pair (i. e. six camels which he had bought from Sa'd), and take them to y, our friends and say: Verily Allah (or he said: Verily Allah's Messenger (ﷺ) has provided you with these animals. So ride upon them. Abu Musa said: I went along with them to my friends and said: Verily Allah's messenger (ﷺ) has provided you with these animals for riding; but by Allah, I shall not leave you until some of you go along with me to him who had heard the talk of Allah's Messenger (ﷺ) then I asked him for you, and his refusal for the first time, and then his granting them to me subsequently; so you should not think that I narrated to you something which he did not say. They said to me: By Allah, in our opinion you are certainly truthful, and we would do as you like. So Abu Musa went along withsome of the menfrom them until they came to those who had heard the words of Allah's Messenger (may, peace be upon him) and his refusal to (provide) them with (animals) ; and subsequently his granting (the animals) to them; and they narrated to them exactly as Abu Masa had narrated to them}}
\hadithdefcmd{muslim}{4265}{حَدَّثَنِي أَبُو الرَّبِيعِ الْعَتَكِيُّ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - عَنْ أَيُّوبَ، عَنْ أَبِي، قِلاَبَةَ وَعَنِ الْقَاسِمِ بْنِ عَاصِمٍ، عَنْ زَهْدَمٍ الْجَرْمِيِّ، - قَالَ أَيُّوبُ وَأَنَا لِحَدِيثِ الْقَاسِمِ، أَحْفَظُ مِنِّي لِحَدِيثِ أَبِي قِلاَبَةَ - قَالَ كُنَّا عِنْدَ أَبِي مُوسَى فَدَعَا بِمَائِدَتِهِ وَعَلَيْهَا لَحْمُ دَجَاجٍ فَدَخَلَ رَجُلٌ مِنْ بَنِي تَيْمِ اللَّهِ أَحْمَرُ شَبِيهٌ بِالْمَوَالِي فَقَالَ لَهُ هَلُمَّ ‏.‏ فَتَلَكَّأَ فَقَالَ هَلُمَّ فَإِنِّي قَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْكُلُ مِنْهُ ‏.‏ فَقَالَ الرَّجُلُ إِنِّي رَأَيْتُهُ يَأْكُلُ شَيْئًا فَقَذِرْتُهُ فَحَلَفْتُ أَنْ لاَ أَطْعَمَهُ فَقَالَ هَلُمَّ أُحَدِّثْكَ عَنْ ذَلِكَ إِنِّي أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي رَهْطٍ مِنَ الأَشْعَرِيِّينَ نَسْتَحْمِلُهُ فَقَالَ ‏"‏ وَاللَّهِ لاَ أَحْمِلُكُمْ وَمَا عِنْدِي مَا أَحْمِلُكُمْ عَلَيْهِ ‏"‏ ‏.‏ فَلَبِثْنَا مَا شَاءَ اللَّهُ فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِنَهْبِ إِبِلٍ فَدَعَا بِنَا فَأَمَرَ لَنَا بِخَمْسِ ذَوْدٍ غُرِّ الذُّرَى قَالَ فَلَمَّا انْطَلَقْنَا قَالَ بَعْضُنَا لِبَعْضٍ أَغْفَلْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم يَمِينَهُ لاَ يُبَارَكُ لَنَا ‏.‏ فَرَجَعْنَا إِلَيْهِ فَقُلْنَا يَا رَسُولَ اللَّهِ إِنَّا أَتَيْنَاكَ نَسْتَحْمِلُكَ وَإِنَّكَ حَلَفْتَ أَنْ لاَ تَحْمِلَنَا ثُمَّ حَمَلْتَنَا أَفَنَسِيتَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ إِنِّي وَاللَّهِ إِنْ شَاءَ اللَّهُ لاَ أَحْلِفُ عَلَى يَمِينٍ فَأَرَى غَيْرَهَا خَيْرًا مِنْهَا إِلاَّ أَتَيْتُ الَّذِي هُوَ خَيْرٌ وَتَحَلَّلْتُهَا فَانْطَلِقُوا فَإِنَّمَا حَمَلَكُمُ اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{4265}\hadithtrans{Ayyub said:We were sitting in the company of Abu Musa that he called for food and it consisted of flesh of fowl. It was then that a person from Banu Tamim visited him. His complexion was red having the resemblance of a slave. He said to him: Come and (join me in food). He showed reluctance. He (Abu Masa) said: Come on, for I saw Allah's Messenger (ﷺ) eating it (fowl's meat), whereupon that person said: I saw it eating something (of filth and rubbish) and I found it repugnant and took an oath that I would never eat that. He (Abu Muds) said: Come, so that I would narrate to you about that (the incident pertaining to vow). (And he narrated thus): I came to Allah's Messenger (ﷺ) along with a group of people belonging to the tribe of Ash'ari, asking him to provide us with riding camels. He (the Holy Prophet) said: By Allah, I cannot provide you with riding animals. And there is nothing with me with which I can provide you a mount. We stayed (for some time) there as Allah willed, and there was brought to Allah's Messenger (ﷺ) booty of camels. He called us and commanded that we should be given five white humped camels. As we were about to go back, some of us said to the other: As we made Allah's Messenger (ﷺ) forget oath, there would be no blessing for us (in his gift). We went back to him and said: Allah's Messenger, we came to you to provide us with riding animals and you took an oath that you would never equip us with mounts and then you have provided us with the riding beasts Allah's Messenger, have you forgotten? Thereupon he said: I swear by Allah that if Allah so wills, I shall not swear an oath, and then consider something else to be better than it without making atonement for my oath and doing the thing that is better. So you go; Allah, the Exalted and Glorious, has given you riding animals}}
\hadithdefcmd{muslim}{4266}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، وَالْقَاسِمِ، التَّمِيمِيِّ عَنْ زَهْدَمٍ الْجَرْمِيِّ، قَالَ كَانَ بَيْنَ هَذَا الْحَىِّ مِنْ جَرْمٍ وَبَيْنَ الأَشْعَرِيِّينَ وُدٌّ وَإِخَاءٌ فَكُنَّا عِنْدَ أَبِي مُوسَى الأَشْعَرِيِّ فَقُرِّبَ إِلَيْهِ طَعَامٌ فِيهِ لَحْمُ دَجَاجٍ ‏.‏ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{4266}\hadithtrans{This hadith has been narrated on the authority of Abu Musa al-Ash'ari with a slight variation of words}}
\hadithdefcmd{muslim}{4267}{وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ، نُمَيْرٍ عَنْ إِسْمَاعِيلَ، ابْنِ عُلَيَّةَ عَنْ أَيُّوبَ، عَنِ الْقَاسِمِ التَّمِيمِيِّ، عَنْ زَهْدَمٍ الْجَرْمِيِّ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ زَهْدَمٍ الْجَرْمِيِّ، ح وَحَدَّثَنِي أَبُو بَكْرِ بْنُ إِسْحَاقَ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، وَالْقَاسِمِ، عَنْ زَهْدَمٍ الْجَرْمِيِّ، قَالَ كُنَّا عِنْدَ أَبِي مُوسَى ‏.‏ وَاقْتَصُّوا جَمِيعًا الْحَدِيثَ بِمَعْنَى حَدِيثِ حَمَّادِ بْنِ زَيْدٍ ‏.‏\hadithno{4267}\hadithtrans{Zahdam al-Jarmi reported:We were in the company of Abu Musa. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{4268}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا الصَّعْقُ، - يَعْنِي ابْنَ حَزْنٍ - حَدَّثَنَا مَطَرٌ الْوَرَّاقُ، حَدَّثَنَا زَهْدَمٌ الْجَرْمِيُّ، قَالَ دَخَلْتُ عَلَى أَبِي مُوسَى وَهُوَ يَأْكُلُ لَحْمَ دَجَاجٍ وَسَاقَ الْحَدِيثَ بِنَحْوِ حَدِيثِهِمْ وَزَادَ فِيهِ قَالَ ‏ "‏ إِنِّي وَاللَّهِ مَا نَسِيتُهَا ‏"‏ ‏.‏\hadithno{4268}\hadithtrans{Zahdam al-Jarmi reported:I visited Abu Musa and lie was eating fowl's meat. The rest of the hadith is the same with this addition that he (the Holy Prophet) said: By Allah, I did not forget it}}
\hadithdefcmd{muslim}{4269}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ ضُرَيْبِ بْنِ، نُقَيْرٍ الْقَيْسِيِّ عَنْ زَهْدَمٍ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم نَسْتَحْمِلُهُ فَقَالَ ‏"‏ مَا عِنْدِي مَا أَحْمِلُكُمْ وَاللَّهِ مَا أَحْمِلُكُمْ ‏"‏ ‏.‏ ثُمَّ بَعَثَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِثَلاَثَةِ ذَوْدٍ بُقْعِ الذُّرَى فَقُلْنَا إِنَّا أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم نَسْتَحْمِلُهُ فَحَلَفَ أَنْ لاَ يَحْمِلَنَا فَأَتَيْنَاهُ فَأَخْبَرْنَاهُ فَقَالَ ‏"‏ إِنِّي لاَ أَحْلِفُ عَلَى يَمِينٍ أَرَى غَيْرَهَا خَيْرًا مِنْهَا إِلاَّ أَتَيْتُ الَّذِي هُوَ خَيْرٌ ‏"‏ ‏.‏\hadithno{4269}\hadithtrans{Abu Musa al-Ash'ari reported:We came to Allah's Messenger (ﷺ) requesting him to provide us with riding camels. He (the Holy Prophet) said: There is nothing with me with which I should equip you. By Allah, I would not provide you with (riding camels). Then Allah's Messenger (ﷺ) sent to us three camels with spotted bumps. We said: We came to Allah's Messenger (ﷺ) asking him to equip us with riding animals. He took an oath that he could not equip us. We came to him and informed him. He said: By Allah, I do not take an oath, but when I find the other thing better than that, I do that which is better}}
\hadithdefcmd{muslim}{4270}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى التَّيْمِيُّ، حَدَّثَنَا الْمُعْتَمِرُ، عَنْ أَبِيهِ، حَدَّثَنَا أَبُو السَّلِيلِ، عَنْ زَهْدَمٍ، يُحَدِّثُهُ عَنْ أَبِي مُوسَى، قَالَ كُنَّا مُشَاةً فَأَتَيْنَا نَبِيَّ اللَّهِ صلى الله عليه وسلم نَسْتَحْمِلُهُ ‏.‏ بِنَحْوِ حَدِيثِ جَرِيرٍ ‏.‏\hadithno{4270}\hadithtrans{Abu Musa reported:We walked on foot and came to Allah's Apostle (may peace he upon him) asking him to provide us with mounts. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{4271}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ الْفَزَارِيُّ، أَخْبَرَنَا يَزِيدُ بْنُ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَعْتَمَ رَجُلٌ عِنْدَ النَّبِيِّ صلى الله عليه وسلم ثُمَّ رَجَعَ إِلَى أَهْلِهِ فَوَجَدَ الصِّبْيَةَ قَدْ نَامُوا فَأَتَاهُ أَهْلُهُ بِطَعَامِهِ فَحَلَفَ لاَ يَأْكُلُ مِنْ أَجْلِ صِبْيَتِهِ ثُمَّ بَدَا لَهُ فَأَكَلَ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ فَرَأَى غَيْرَهَا خَيْرًا مِنْهَا فَلْيَأْتِهَا وَلْيُكَفِّرْ عَنْ يَمِينِهِ ‏"‏ ‏.‏\hadithno{4271}\hadithtrans{Abu Huraira reported:A person sat late in the night with Allah's Apostle (ﷺ), and then came to his family and found that his children had gone to sleep. His wife brought food for him. but he took an oath that he would not eat because of his children (having gone to sleep without food) He then gave precedence (of breaking the vow and then expiating it) and ate the food He then came to Allah s Messenger (ﷺ) and made mention of that to him, whereupon Allah's Messenger (may peace he upon him) said: He who took an oath and (later on) found something better than that should do that, and expiate for (breaking) his vow}}
\hadithdefcmd{muslim}{4272}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي مَالِكٌ، عَنْ سُهَيْلِ بْنِ أَبِي، صَالِحٍ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ فَرَأَى غَيْرَهَا خَيْرًا مِنْهَا فَلْيُكَفِّرْ عَنْ يَمِينِهِ وَلْيَفْعَلْ ‏"‏ ‏.‏\hadithno{4272}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:He who took an oath and then found another thing better than (this) should expiate for the oath (broken) by him and do (the better thing)}}
\hadithdefcmd{muslim}{4273}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا ابْنُ أَبِي أُوَيْسٍ، حَدَّثَنِي عَبْدُ الْعَزِيزِ بْنُ الْمُطَّلِبِ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ فَرَأَى غَيْرَهَا خَيْرًا مِنْهَا فَلْيَأْتِ الَّذِي هُوَ خَيْرٌ وَلْيُكَفِّرْ عَنْ يَمِينِهِ ‏"‏ ‏.‏\hadithno{4273}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:He who took an oath and (later on) found another thing better than that, he should do that which is better, and expiate for the vow (broken by him)}}
\hadithdefcmd{muslim}{4274}{وَحَدَّثَنِي الْقَاسِمُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنِي سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - حَدَّثَنِي سُهَيْلٌ، فِي هَذَا الإِسْنَادِ بِمَعْنَى حَدِيثِ مَالِكٍ ‏ "‏ فَلْيُكَفِّرْ يَمِينَهُ وَلْيَفْعَلِ الَّذِي هُوَ خَيْرٌ ‏"‏ ‏.‏\hadithno{4274}\hadithtrans{This hadith is narrated on the authority of Suhail with the same chain of transmitters (with these words):" He should expiate for (breaking) the vow and do that which is better}}
\hadithdefcmd{muslim}{4275}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ عَبْدِ الْعَزِيزِ، - يَعْنِي ابْنَ رُفَيْعٍ - عَنْ تَمِيمِ بْنِ طَرَفَةَ، قَالَ جَاءَ سَائِلٌ إِلَى عَدِيِّ بْنِ حَاتِمٍ فَسَأَلَهُ نَفَقَةً فِي ثَمَنِ خَادِمٍ أَوْ فِي بَعْضِ ثَمَنِ خَادِمٍ ‏.‏ فَقَالَ لَيْسَ عِنْدِي مَا أُعْطِيكَ إِلاَّ دِرْعِي وَمِغْفَرِي فَأَكْتُبُ إِلَى أَهْلِي أَنْ يُعْطُوكَهَا ‏.‏ قَالَ فَلَمْ يَرْضَ فَغَضِبَ عَدِيٌّ فَقَالَ أَمَا وَاللَّهِ لاَ أُعْطِيكَ شَيْئًا ثُمَّ إِنَّ الرَّجُلَ رَضِيَ فَقَالَ أَمَا وَاللَّهِ لَوْلاَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ ثُمَّ رَأَى أَتْقَى لِلَّهِ مِنْهَا فَلْيَأْتِ التَّقْوَى ‏"‏ ‏.‏ مَا حَنَّثْتُ يَمِينِي ‏.‏\hadithno{4275}\hadithtrans{Tamim b. Tarafa reported:A beggar came to 'Adi b. Hatim and he begged him to give him the price of a slave, or some portion of the price of the slave. He ('Adi) said: I have nothing to give you except my coat-of-mail and helmet. I will, however, write to my family to give that to you, but he did not agree to that. Thereupon 'Adi was enraged, and said: By Allah, I will not give you anything. The person (then) agreed to accept that, whereupon he said: By Allah, had I not heard Allah's Messenger (ﷺ) saying:" He who took an oath, but then found something more pious in the sight of Allah, he should (break the oath) and do that which is more pious," I would not have broken the oath (and thus paid you anything)}}
\hadithdefcmd{muslim}{4276}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنْ تَمِيمِ بْنِ طَرَفَةَ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ فَرَأَى غَيْرَهَا خَيْرًا مِنْهَا فَلْيَأْتِ الَّذِي هُوَ خَيْرٌ وَلْيَتْرُكْ يَمِينَهُ ‏"‏ ‏.‏\hadithno{4276}\hadithtrans{Adi b. Hatim reported Allah's Messenger (ﷺ) as saying:He who took an oath, but he found something else better than that, should do that which is better and break his oath}}
\hadithdefcmd{muslim}{4277}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَمُحَمَّدُ بْنُ طَرِيفٍ الْبَجَلِيُّ، - وَاللَّفْظُ لاِبْنِ طَرِيفٍ - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنْ تَمِيمٍ الطَّائِيِّ، عَنْ عَدِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا حَلَفَ أَحَدُكُمْ عَلَى الْيَمِينِ فَرَأَى خَيْرًا مِنْهَا فَلْيُكَفِّرْهَا وَلْيَأْتِ الَّذِي هُوَ خَيْرٌ ‏"‏ ‏.‏\hadithno{4277}\hadithtrans{Adi reported Allah's Messenger (ﷺ) as saying:When anyone amongst you takes an oath, but he finds (something) better than that he should expiate (the breaking of the oath), and do that which is better}}
\hadithdefcmd{muslim}{4278}{وَحَدَّثَنَا مُحَمَّدُ بْنُ طَرِيفٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنِ الشَّيْبَانِيِّ، عَنْ عَبْدِ الْعَزِيزِ، بْنِ رُفَيْعٍ عَنْ تَمِيمٍ الطَّائِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ذَلِكَ ‏.‏\hadithno{4278}\hadithtrans{This hadith is reported on the authority of Adi b. Hatim through another chain of transmitters}}
\hadithdefcmd{muslim}{4279}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ تَمِيمِ بْنِ طَرَفَةَ، قَالَ سَمِعْتُ عَدِيَّ بْنَ حَاتِمٍ، وَأَتَاهُ، رَجُلٌ يَسْأَلُهُ مِائَةَ دِرْهَمٍ ‏.‏ فَقَالَ تَسْأَلُنِي مِائَةَ دِرْهَمٍ وَأَنَا ابْنُ حَاتِمٍ وَاللَّهِ لاَ أُعْطِيكَ ‏.‏ ثُمَّ قَالَ لَوْلاَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ ثُمَّ رَأَى خَيْرًا مِنْهَا فَلْيَأْتِ الَّذِي هُوَ خَيْرٌ ‏"‏ ‏.‏\hadithno{4279}\hadithtrans{Tamim b. Tarafa reported that he heard 'Adi b. Hatim say that a person came to him and asked for one hundred dirhams. He ('Adi) said:You asked me for one hundred dirhams and I am the son of Hatim; by Allah, I will not give you. But then he said: (I would have done that) if I had not heard Allah's Messenger (ﷺ) say: He who takes an oath, but then finds something better than that, should do that which is better}}
\hadithdefcmd{muslim}{4280}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا سِمَاكُ بْنُ حَرْبٍ، قَالَ سَمِعْتُ تَمِيمَ بْنَ طَرَفَةَ، قَالَ سَمِعْتُ عَدِيَّ بْنَ حَاتِمٍ، أَنَّ رَجُلاً، سَأَلَهُ فَذَكَرَ مِثْلَهُ وَزَادَ وَلَكَ أَرْبَعُمِائَةٍ فِي عَطَائِي ‏.‏\hadithno{4280}\hadithtrans{Tamim b. Tarafa reported:I heard 'Adi b. Hatim say that a person asked that and then narrated (the hadith) like one (mentioned above), but he made this addition:" Here are four hundred (dirhams) for you out of my gift}}
\hadithdefcmd{muslim}{4281}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، حَدَّثَنَا الْحَسَنُ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، بْنُ سَمُرَةَ قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا عَبْدَ الرَّحْمَنِ بْنَ سَمُرَةَ لاَ تَسْأَلِ الإِمَارَةَ فَإِنَّكَ إِنْ أُعْطِيتَهَا عَنْ مَسْأَلَةٍ وُكِلْتَ إِلَيْهَا وَإِنْ أُعْطِيتَهَا عَنْ غَيْرِ مَسْأَلَةٍ أُعِنْتَ عَلَيْهَا وَإِذَا حَلَفْتَ عَلَى يَمِينٍ فَرَأَيْتَ غَيْرَهَا خَيْرًا مِنْهَا فَكَفِّرْ عَنْ يَمِينِكَ وَائْتِ الَّذِي هُوَ خَيْرٌ ‏"‏ ‏.‏ قَالَ أَبُو أَحْمَدَ الْجُلُودِيُّ حَدَّثَنَا أَبُو الْعَبَّاسِ الْمَاسَرْجَسِيُّ، حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، ‏.‏ بِهَذَا الْحَدِيثِ ‏.‏\hadithno{4281}\hadithtrans{Abd al-Rahman b. Samura reported that Allah's Messenger (ﷺ) said to me:Abd al-Rahman b. Samura, don't ask for authority for if it is granted to you for asking for it, you would be commissioned for it (without having the support of Allah), but if you are granted it without your asking for it. You would be helped (by Allah) in it. And when you take an oath and find something else better than that, expiate for (breaking) your oath, and do that which is better. This hadith has also been transmitted on the authority of Ibn Farrukh. The above hadith is narratted through another chain of transmitters}}
\hadithdefcmd{muslim}{4282}{حَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، حَدَّثَنَا هُشَيْمٌ، عَنْ يُونُسَ، وَمَنْصُورٍ، وَحُمَيْدٍ، ح وَحَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ سِمَاكِ بْنِ عَطِيَّةَ، وَيُونُسَ بْنِ عُبَيْدٍ، وَهِشَامِ، بْنِ حَسَّانَ فِي آخَرِينَ ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا الْمُعْتَمِرُ، عَنْ أَبِيهِ، ح وَحَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ الْعَمِّيُّ، حَدَّثَنَا سَعِيدُ بْنُ عَامِرٍ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، كُلُّهُمْ عَنِ الْحَسَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِهَذَا الْحَدِيثِ وَلَيْسَ فِي حَدِيثِ الْمُعْتَمِرِ عَنْ أَبِيهِ ذِكْرُ الإِمَارَةِ ‏.‏\hadithno{4282}\hadithtrans{This hadith has been narrated on the authority of 'Abd al-Rahman b. Samura through another chain of transmitters but there is no mention of the word" authority}}
\hadithdefcmd{muslim}{4283}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَعَمْرٌو النَّاقِدُ، - قَالَ يَحْيَى أَخْبَرَنَا هُشَيْمُ بْنُ بَشِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي صَالِحٍ، وَقَالَ، عَمْرٌو حَدَّثَنَا هُشَيْمُ بْنُ بَشِيرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ أَبِي صَالِحٍ، - عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَمِينُكَ عَلَى مَا يُصَدِّقُكَ عَلَيْهِ صَاحِبُكَ ‏"‏ ‏.‏ وَقَالَ عَمْرٌو ‏"‏ يُصَدِّقُكَ بِهِ صَاحِبُكَ ‏"‏ ‏.‏\hadithno{4283}\hadithtrans{Abu Haraira reported Allah's Messenger (ﷺ) as saying:Your oath should be about something regarding which your companion will believe you. 'Amr said: By which your companion will believe you}}
\hadithdefcmd{muslim}{4284}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ هُشَيْمٍ، عَنْ عَبَّادِ بْنِ، أَبِي صَالِحٍ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْيَمِينُ عَلَى نِيَّةِ الْمُسْتَحْلِفِ ‏"‏ ‏.‏\hadithno{4284}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:An oath is to be interpreted according to the intention of the one who takes it}}
\hadithdefcmd{muslim}{4285}{حَدَّثَنِي أَبُو الرَّبِيعِ الْعَتَكِيُّ، وَأَبُو كَامِلٍ الْجَحْدَرِيُّ فُضَيْلُ بْنُ حُسَيْنٍ - وَاللَّفْظُ لأَبِي الرَّبِيعِ - قَالاَ حَدَّثَنَا حَمَّادٌ، - وَهُوَ ابْنُ زَيْدٍ - حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ لِسُلَيْمَانَ سِتُّونَ امْرَأَةً فَقَالَ لأَطُوفَنَّ عَلَيْهِنَّ اللَّيْلَةَ فَتَحْمِلُ كُلُّ وَاحِدَةٍ مِنْهُنَّ فَتَلِدُ كُلُّ وَاحِدَةٍ مِنْهُنَّ غُلاَمًا فَارِسًا يُقَاتِلُ فِي سَبِيلِ اللَّهِ فَلَمْ تَحْمِلْ مِنْهُنَّ إِلاَّ وَاحِدَةٌ فَوَلَدَتْ نِصْفَ إِنْسَانٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ كَانَ اسْتَثْنَى لَوَلَدَتْ كُلُّ وَاحِدَةٍ مِنْهُنَّ غُلاَمًا فَارِسًا يُقَاتِلُ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏\hadithno{4285}\hadithtrans{Abu Huraira reported that (Hadrat) Sulaiman had sixty wives. He (one day) said:I will visit each one of them every night, and every one of them will become pregnant and give birth to a male child who will be a horseman and fight in the cause of Allah. But (it so happened) that none of them became pregnant except one, but she gave birth to an incomplete child. Thereupon Allah's Messenger (ﷺ) said: Had he said Insha' Allah (if God so wills), then every one of them would have given birth to a child who would have been a horseman and fought in the cause of Allah}}
\hadithdefcmd{muslim}{4286}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لاِبْنِ أَبِي عُمَرَ - قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ حُجَيْرٍ، عَنْ طَاوُسٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ قَالَ سُلَيْمَانُ بْنُ دَاوُدَ نَبِيُّ اللَّهِ لأَطُوفَنَّ اللَّيْلَةَ عَلَى سَبْعِينَ امْرَأَةً كُلُّهُنَّ تَأْتِي بِغُلاَمٍ يُقَاتِلُ فِي سَبِيلِ اللَّهِ ‏.‏ فَقَالَ لَهُ صَاحِبُهُ أَوِ الْمَلَكُ قُلْ إِنْ شَاءَ اللَّهُ ‏.‏ فَلَمْ يَقُلْ وَنَسِيَ ‏.‏ فَلَمْ تَأْتِ وَاحِدَةٌ مِنْ نِسَائِهِ إِلاَّ وَاحِدَةٌ جَاءَتْ بِشِقِّ غُلاَمٍ ‏"‏ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَلَوْ قَالَ إِنْ شَاءَ اللَّهُ ‏.‏ لَمْ يَحْنَثْ وَكَانَ دَرَكًا لَهُ فِي حَاجَتِهِ ‏"‏ ‏.‏\hadithno{4286}\hadithtrans{Abu Huraira reported Allah's Prophet (ﷺ) as saying that Sulaiman b. Dawud, the Messenger of Allah, observed:I will have an intercourse with seventy wives during the night; all of them will give birth to a male child who will fight in the cause of Allah. His companion or the ang I said to him: Say," If God wills." But he (Hadrat Sulaimin) did not say so, and he forgot it. And none of his wives gave birth to a child, but one who gave birth to a premature child. Allah's Messenger (ﷺ) said: Had he said Insha' Allah (if God so will). he would not have failed and his desire would have been materialised}}
\hadithdefcmd{muslim}{4287}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ أَوْ نَحْوَهُ ‏.‏\hadithno{4287}\hadithtrans{Abu Huraira reported this hadith from the Messenger of Allah (ﷺ) through another chain of transmitters}}
\hadithdefcmd{muslim}{4288}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ بْنُ هَمَّامٍ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ سُلَيْمَانُ بْنُ دَاوُدَ لأُطِيفَنَّ اللَّيْلَةَ عَلَى سَبْعِينَ امْرَأَةً تَلِدُ كُلُّ امْرَأَةٍ مِنْهُنَّ غُلاَمًا يُقَاتِلُ فِي سَبِيلِ اللَّهِ ‏.‏ فَقِيلَ لَهُ قُلْ إِنْ شَاءَ اللَّهُ ‏.‏ فَلَمْ يَقُلْ ‏.‏ فَأَطَافَ بِهِنَّ فَلَمْ تَلِدْ مِنْهُنَّ إِلاَّ امْرَأَةٌ وَاحِدَةٌ نِصْفَ إِنْسَانٍ ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ قَالَ إِنْ شَاءَ اللَّهُ ‏.‏ لَمْ يَحْنَثْ وَكَانَ دَرَكًا لِحَاجَتِهِ ‏"‏ ‏.‏\hadithno{4288}\hadithtrans{Abu Huraira reported that Sulaiman b. Dawud said:I will certainly have intercourse with seventy wives during the night, and every wife amongst them will give birth to a child, who will fight in the cause of Allah. It was said to him: Say:" Insha' Allah" (God willing), but he did not say so and forgot it. He went round them but none of them give birth to a child except one woman and that too was an incomplete person. Upon this Allah's Messenger (ﷺ) said: If he had said" Insha' Allah." he would not have failed, and his desire must have been fulfilled}}
\hadithdefcmd{muslim}{4289}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنِي وَرْقَاءُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ سُلَيْمَانُ بْنُ دَاوُدَ لأَطُوفَنَّ اللَّيْلَةَ عَلَى تِسْعِينَ امْرَأَةً كُلُّهَا تَأْتِي بِفَارِسٍ يُقَاتِلُ فِي سَبِيلِ اللَّهِ ‏.‏ فَقَالَ لَهُ صَاحِبُهُ قُلْ إِنْ شَاءَ اللَّهُ ‏.‏ فَلَمْ يَقُلْ إِنْ شَاءَ اللَّهُ ‏.‏ فَطَافَ عَلَيْهِنَّ جَمِيعًا فَلَمْ تَحْمِلْ مِنْهُنَّ إِلاَّ امْرَأَةٌ وَاحِدَةٌ فَجَاءَتْ بِشِقِّ رَجُلٍ وَايْمُ الَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَوْ قَالَ إِنْ شَاءَ اللَّهُ ‏.‏ لَجَاهَدُوا فِي سَبِيلِ اللَّهِ فُرْسَانًا أَجْمَعُونَ ‏"‏ ‏.‏\hadithno{4289}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying that Sulaiman b. Dawud (once) said:I will go round in the night to my ninety wives, and every one of them will give birth to a child (who will grow up) as a horseman and fight in the cause of Allah His companions said to him: Say" Insha' Allah." but he did not say Inshii' Allah. He went round all of them but none of them became pregnant but one, and she gave birth to a premature child. And by Him in Whose hand is the life of Muhammad, if he had said, Insha' Allah (his wives would have given birth to the children who would all have grown up into horsemen and fought in the way of Allah)}}
\hadithdefcmd{muslim}{4290}{وَحَدَّثَنِيهِ سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا حَفْصُ بْنُ مَيْسَرَةَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ أَبِي، الزِّنَادِ بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏ غَيْرَ أَنَّهُ قَالَ ‏ "‏ كُلُّهَا تَحْمِلُ غُلاَمًا يُجَاهِدُ فِي سَبِيلِ اللَّهِ ‏"‏‏.‏\hadithno{4290}\hadithtrans{This hadith has been narrated on the authority of Abu Zinad with the same chain of transmitters with a variation of (these words):" Every one of them giving birth to a child, who would have fought in the cause of Allah}}
\hadithdefcmd{muslim}{4291}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَاللَّهِ لأَنْ يَلَجَّ أَحَدُكُمْ بِيَمِينِهِ فِي أَهْلِهِ آثَمُ لَهُ عِنْدَ اللَّهِ مِنْ أَنْ يُعْطِيَ كَفَّارَتَهُ الَّتِي فَرَضَ اللَّهُ ‏"‏ ‏.‏\hadithno{4291}\hadithtrans{Hammam b. Munabbih reported:This is what Abu Huraira reported to us from Allah's Messenger (ﷺ), and he narrated a hadith and (one) of them is that Allah's Messenger (ﷺ) said: I swear by Allah, it is more sinful in Allah's sight for one of you to persist in an oath regarding his family than payment of its expiation which Allah has imposed upon him (for breaking the oath)}}
\hadithdefcmd{muslim}{4292}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَزُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لِزُهَيْرٍ - قَالُوا حَدَّثَنَا يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ عُمَرَ، قَالَ يَا رَسُولَ اللَّهِ إِنِّي نَذَرْتُ فِي الْجَاهِلِيَّةِ أَنْ أَعْتَكِفَ لَيْلَةً فِي الْمَسْجِدِ الْحَرَامِ ‏.‏ قَالَ ‏ "‏ فَأَوْفِ بِنَذْرِكَ ‏"‏ ‏.‏\hadithno{4292}\hadithtrans{Ibn 'Umar reported that Umar (b. Khattab) said:Messenger of Allah, I had taken a vow during the days of Ignorance (Jahiliyya) that I would observe I'tikaf for a night in the Sacred Mosque. He (the Holy Prophet) said: Fulfil your vow}}
\hadithdefcmd{muslim}{4293}{وَحَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ يَعْنِي الثَّقَفِيَّ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، وَإِسْحَاقُ، بْنُ إِبْرَاهِيمَ جَمِيعًا عَنْ حَفْصِ بْنِ غِيَاثٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ جَبَلَةَ بْنِ أَبِي رَوَّادٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، كُلُّهُمْ عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، وَقَالَ، حَفْصٌ مِنْ بَيْنِهِمْ عَنْ عُمَرَ، بِهَذَا الْحَدِيثِ أَمَّا أَبُو أُسَامَةَ وَالثَّقَفِيُّ فَفِي حَدِيثِهِمَا اعْتِكَافُ لَيْلَةٍ ‏.‏ وَأَمَّا فِي حَدِيثِ شُعْبَةَ فَقَالَ جَعَلَ عَلَيْهِ يَوْمًا يَعْتَكِفُهُ ‏.‏ وَلَيْسَ فِي حَدِيثِ حَفْصٍ ذِكْرُ يَوْمٍ وَلاَ لَيْلَةٍ ‏.‏\hadithno{4293}\hadithtrans{This hadith is transmitted on the authority of Ibn Umar with a slight variation of words}}
\hadithdefcmd{muslim}{4294}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، أَنَّ أَيُّوبَ، حَدَّثَهُ أَنَّ نَافِعًا حَدَّثَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ حَدَّثَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ بِالْجِعْرَانَةِ بَعْدَ أَنْ رَجَعَ مِنَ الطَّائِفِ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي نَذَرْتُ فِي الْجَاهِلِيَّةِ أَنْ أَعْتَكِفَ يَوْمًا فِي الْمَسْجِدِ الْحَرَامِ فَكَيْفَ تَرَى قَالَ ‏ "‏ اذْهَبْ فَاعْتَكِفْ يَوْمًا ‏"‏ ‏.‏ قَالَ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَدْ أَعْطَاهُ جَارِيَةً مِنَ الْخُمْسِ فَلَمَّا أَعْتَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَبَايَا النَّاسِ سَمِعَ عُمَرُ بْنُ الْخَطَّابِ أَصْوَاتَهُمْ يَقُولُونَ أَعْتَقَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ مَا هَذَا فَقَالُوا أَعْتَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَبَايَا النَّاسِ ‏.‏ فَقَالَ عُمَرُ يَا عَبْدَ اللَّهِ اذْهَبْ إِلَى تِلْكَ الْجَارِيَةِ فَخَلِّ سَبِيلَهَا ‏.‏\hadithno{4294}\hadithtrans{Abdullah b. 'Umar reported that 'Umar b. Khattab asked the Messenger of Allah (ﷺ) as he was at ji'rana (a town near Mecca) on his way back from Ta'if:Messenger of Allah, I had taken a vow during the days of Ignorance that I would observe I'tikaf for one day in the Sacred Mosque. So what is your opinion? He said: Go and observe I'tikaf for a day. And Allah's Messenger (ﷺ) gave him a slave girl out of the one-fifth (of the spoils of war meant for the Holy Prophet). And when Allah's Messenger (inay peace be upon him) set the war prisoners free. 'Umar b. Khattab heard their voice as they were saying: Allah's Messenger (ﷺ) has set as free. He (Hadrat 'Umar) said: What is this? They said: Allah's Messenger (ﷺ) has set free the prisoners of war (which had fallen to the lot of people). Thereupon he (Hadrat 'Umar) said: Abdullah, go to that slave-girl and set her free}}
\hadithdefcmd{muslim}{4295}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ لَمَّا قَفَلَ النَّبِيُّ صلى الله عليه وسلم مِنْ حُنَيْنٍ سَأَلَ عُمَرُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ نَذْرٍ كَانَ نَذَرَهُ فِي الْجَاهِلِيَّةِ اعْتِكَافِ يَوْمٍ ‏.‏ ثُمَّ ذَكَرَ بِمَعْنَى حَدِيثِ جَرِيرِ بْنِ حَازِمٍ ‏.‏\hadithno{4295}\hadithtrans{lbn 'Umar reported:When Allah's Apostle (ﷺ) came back from the Battle of Hunain, Umar asked Allah's Messenger (ﷺ) about the vow he had taken during the days of Ignorance that he would observe I'tikaf for a day. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{4296}{وَحَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، قَالَ ذُكِرَ عِنْدَ ابْنِ عُمَرَ عُمْرَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الْجِعْرَانَةِ فَقَالَ لَمْ يَعْتَمِرْ مِنْهَا - قَالَ - وَكَانَ عُمَرُ نَذَرَ اعْتِكَافَ لَيْلَةٍ فِي الْجَاهِلِيَّةِ ‏.‏ ثُمَّ ذَكَرَ نَحْوَ حَدِيثِ جَرِيرِ بْنِ حَازِمٍ وَمَعْمَرٍ عَنْ أَيُّوبَ ‏.‏\hadithno{4296}\hadithtrans{Nafi' reported:A mention of Allah's Messenger (ﷺ) observing 'Umra from ja'rina was made before Ibn 'Umar. He said: He did not enter into the state of Ihram from that (place), and Umar had taken a vow of observing I'tikaf for a night during the days of Ignorance. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{4297}{وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، حَدَّثَنَا حَجَّاجُ بْنُ الْمِنْهَالِ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، ح وَحَدَّثَنَا يَحْيَى بْنُ خَلَفٍ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، كِلاَهُمَا عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، ‏.‏ بِهَذَا الْحَدِيثِ فِي النَّذْرِ وَفِي حَدِيثِهِمَا جَمِيعًا اعْتِكَافُ يَوْمٍ ‏.‏\hadithno{4297}\hadithtrans{This hadith has been transmitted on the authority of Ibn Umar through another chain of transmitters but with a slight variation of words}}
\hadithdefcmd{muslim}{4298}{حَدَّثَنِي أَبُو كَامِلٍ، فُضَيْلُ بْنُ حُسَيْنٍ الْجَحْدَرِيُّ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ فِرَاسٍ، عَنْ ذَكْوَانَ أَبِي صَالِحٍ، عَنْ زَاذَانَ أَبِي عُمَرَ، قَالَ أَتَيْتُ ابْنَ عُمَرَ وَقَدْ أَعْتَقَ مَمْلُوكًا - قَالَ - فَأَخَذَ مِنَ الأَرْضِ عُودًا أَوْ شَيْئًا فَقَالَ مَا فِيهِ مِنَ الأَجْرِ مَا يَسْوَى هَذَا إِلاَّ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ لَطَمَ مَمْلُوكَهُ أَوْ ضَرَبَهُ فَكَفَّارَتُهُ أَنْ يُعْتِقَهُ ‏"‏\hadithno{4298}\hadithtrans{Zadhan Abl Umar reported:I came to Ibn 'Umar as he had granted freedom to a stave. He (the narrator further) said: He took hold of a wood or something like it from the earth and said: It (freedom of a slave) has not the reward evert equal to it, but the fact that I heard Allah's Messenger (way peace be upon him) say: He who slaps his slave or beats him, the expiation for it is that he should set him free}}
\hadithdefcmd{muslim}{4299}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ فِرَاسٍ، قَالَ سَمِعْتُ ذَكْوَانَ، يُحَدِّثُ عَنْ زَاذَانَ، أَنَّ ابْنَ عُمَرَ، دَعَا بِغُلاَمٍ لَهُ فَرَأَى بِظَهْرِهِ أَثَرًا فَقَالَ لَهُ أَوْجَعْتُكَ قَالَ لاَ ‏.‏ قَالَ فَأَنْتَ عَتِيقٌ ‏.‏ قَالَ ثُمَّ أَخَذَ شَيْئًا مِنَ الأَرْضِ فَقَالَ مَا لِي فِيهِ مِنَ الأَجْرِ مَا يَزِنُ هَذَا إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ ضَرَبَ غُلاَمًا لَهُ حَدًّا لَمْ يَأْتِهِ أَوْ لَطَمَهُ فَإِنَّ كَفَّارَتَهُ أَنْ يُعْتِقَهُ ‏"‏ ‏.‏\hadithno{4299}\hadithtrans{Zadhan reported that Ibn Umar called his slave and he found the marks (of beating) upon his back. He said to him:I have caused you pain. He said: No. But he (Ibn Umar) said: You are free. He then took hold of something from the earth and said: There is no reward for me even to the weight equal to it. I heard Allah's Messenger (ﷺ) as saying: He who beats a slave without cognizable offence of his or slaps him (without any serious fault), then expiation for it is that he should set him free}}
\hadithdefcmd{muslim}{4300}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، كِلاَهُمَا عَنْ سُفْيَانَ، عَنْ فِرَاسٍ، بِإِسْنَادِ شُعْبَةَ وَأَبِي عَوَانَةَ أَمَّا حَدِيثُ ابْنِ مَهْدِيٍّ فَذَكَرَ فِيهِ ‏"‏ حَدًّا لَمْ يَأْتِهِ ‏"‏ ‏.‏ وَفِي حَدِيثِ وَكِيعٍ ‏"‏ مَنْ لَطَمَ عَبْدَهُ ‏"‏ ‏.‏ وَلَمْ يَذْكُرِ الْحَدَّ‏.‏\hadithno{4300}\hadithtrans{This hadith has been narrated through another chain of transmitters with a slight variation of words}}
\hadithdefcmd{muslim}{4301}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ مُعَاوِيَةَ بْنِ سُوَيْدٍ، قَالَ لَطَمْتُ مَوْلًى لَنَا فَهَرَبْتُ ثُمَّ جِئْتُ قُبَيْلَ الظُّهْرِ فَصَلَّيْتُ خَلْفَ أَبِي فَدَعَاهُ وَدَعَانِي ثُمَّ قَالَ امْتَثِلْ مِنْهُ ‏.‏ فَعَفَا ثُمَّ قَالَ كُنَّا بَنِي مُقَرِّنٍ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم لَيْسَ لَنَا إِلاَّ خَادِمٌ وَاحِدَةٌ فَلَطَمَهَا أَحَدُنَا فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَعْتِقُوهَا ‏"‏ ‏.‏ قَالُوا لَيْسَ لَهُمْ خَادِمٌ غَيْرُهَا قَالَ ‏"‏ فَلْيَسْتَخْدِمُوهَا فَإِذَا اسْتَغْنَوْا عَنْهَا فَلْيُخَلُّوا سَبِيلَهَا ‏"‏ ‏.‏\hadithno{4301}\hadithtrans{Mu'awiya b. Suwaid reported:I slapped a slave belonging to us and then fled away. I came back just before noon and offered prayer behind my father. He called him (the slave) and me and said: Do as he has done to you. He granted pardon. He (my father) then said: We belonged to the family of Muqarrin during the lifetime of Allah's Messenger (may peace be upon him. and had only one slave-girl and one of us slapped her. This news reached Allah's Apostle (ﷺ) and he said: Set her free. They (the members of the family) said: There is no other servant except she. Thereupon he said: Then employ her and when you can afford to dispense with her services, then set her free}}
\hadithdefcmd{muslim}{4302}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالاَ حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ حُصَيْنٍ، عَنْ هِلاَلِ بْنِ يَسَافٍ، قَالَ عَجِلَ شَيْخٌ فَلَطَمَ خَادِمًا لَهُ فَقَالَ لَهُ سُوَيْدُ بْنُ مُقَرِّنٍ عَجَزَ عَلَيْكَ إِلاَّ حُرُّ وَجْهِهَا لَقَدْ رَأَيْتُنِي سَابِعَ سَبْعَةٍ مِنْ بَنِي مُقَرِّنٍ مَا لَنَا خَادِمٌ إِلاَّ وَاحِدَةٌ لَطَمَهَا أَصْغَرُنَا فَأَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نُعْتِقَهَا ‏.‏\hadithno{4302}\hadithtrans{Hilal b. Yasaf reported that a person got angry and slapped his slave-girl. Thereupon Suwaid b. Muqarrin said to him:You could find no other part (to slap) but the prominent part of her face. See I was one of the seven sons of Muqarrin, and we had but only one slave-girl. The youngest of us slapped her, and Allah's Messenger (ﷺ) commanded us to set her free}}
\hadithdefcmd{muslim}{4303}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ حُصَيْنٍ، عَنْ هِلاَلِ بْنِ يَسَافٍ، قَالَ كُنَّا نَبِيعُ الْبَزَّ فِي دَارِ سُوَيْدِ بْنِ مُقَرِّنٍ أَخِي النُّعْمَانِ بْنِ مُقَرِّنٍ فَخَرَجَتْ جَارِيَةٌ فَقَالَتْ لِرَجُلٍ مِنَّا كَلِمَةً فَلَطَمَهَا فَغَضِبَ سُوَيْدٌ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ ابْنِ إِدْرِيسَ ‏.‏\hadithno{4303}\hadithtrans{Hilal b. Yasaf reported:We used to sell cloth in the house of Suwaid b. Muqarrin, the brother of Nu'man b. Muqarrin. There came out a slave-girl, and she said something to a person amongst us, and he slapped her. Suwaid was enraged-the rest of the hadlth is the same}}
\hadithdefcmd{muslim}{4304}{وَحَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ، حَدَّثَنِي أَبِي، حَدَّثَنَا شُعْبَةُ، قَالَ قَالَ لِي مُحَمَّدُ بْنُ الْمُنْكَدِرِ مَا اسْمُكَ قُلْتُ شُعْبَةُ ‏.‏ فَقَالَ مُحَمَّدٌ حَدَّثَنِي أَبُو شُعْبَةَ الْعِرَاقِيُّ عَنْ سُوَيْدِ بْنِ مُقَرِّنٍ أَنَّ جَارِيَةً لَهُ لَطَمَهَا إِنْسَانٌ فَقَالَ لَهُ سُوَيْدٌ أَمَا عَلِمْتَ أَنَّ الصُّورَةَ مُحَرَّمَةٌ فَقَالَ لَقَدْ رَأَيْتُنِي وَإِنِّي لَسَابِعُ إِخْوَةٍ لِي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَمَا لَنَا خَادِمٌ غَيْرُ وَاحِدٍ فَعَمَدَ أَحَدُنَا فَلَطَمَهُ فَأَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نُعْتِقَهُ ‏.‏\hadithno{4304}\hadithtrans{Suwaid b. Muqarrin reported that he had a slave-girl and a person (one of the members of the family) slapped her, whereupon Suwaid said to him:Don't you know that it is forbidden (to strike the) face. He said: You see I was the seventh one amongst my brothers during the lifetime of Allah's Messenger (ﷺ), and we had but only one servant. One of us got enraged and slapped him. Thereupon Allah's Messenger (ﷺ) commanded us to set him free}}
\hadithdefcmd{muslim}{4305}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ وَهْبِ بْنِ جَرِيرٍ، أَخْبَرَنَا شُعْبَةُ، قَالَ قَالَ لِي مُحَمَّدُ بْنُ الْمُنْكَدِرِ مَا اسْمُكَ فَذَكَرَ بِمِثْلِ حَدِيثِ عَبْدِ الصَّمَدِ ‏.‏\hadithno{4305}\hadithtrans{Wahb b. Jarir reported:Shu'ba informed that Muhammad b. Munkadir said to me: What is your name? The rest of the hadith is the same}}
\hadithdefcmd{muslim}{4306}{حَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، - يَعْنِي ابْنَ زِيَادٍ - حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، قَالَ قَالَ أَبُو مَسْعُودٍ الْبَدْرِيُّ كُنْتُ أَضْرِبُ غُلاَمًا لِي بِالسَّوْطِ فَسَمِعْتُ صَوْتًا مِنْ خَلْفِي ‏"‏ اعْلَمْ أَبَا مَسْعُودٍ ‏"‏ ‏.‏ فَلَمْ أَفْهَمِ الصَّوْتَ مِنَ الْغَضَبِ - قَالَ - فَلَمَّا دَنَا مِنِّي إِذَا هُوَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَإِذَا هُوَ يَقُولُ ‏"‏ اعْلَمْ أَبَا مَسْعُودٍ اعْلَمْ أَبَا مَسْعُودٍ ‏"‏ ‏.‏ قَالَ فَأَلْقَيْتُ السَّوْطَ مِنْ يَدِي فَقَالَ ‏"‏ اعْلَمْ أَبَا مَسْعُودٍ أَنَّ اللَّهَ أَقْدَرُ عَلَيْكَ مِنْكَ عَلَى هَذَا الْغُلاَمِ ‏"‏ ‏.‏ قَالَ فَقُلْتُ لاَ أَضْرِبُ مَمْلُوكًا بَعْدَهُ أَبَدًا ‏.‏\hadithno{4306}\hadithtrans{Abu Mas'ud al-Badri reported:I was beating my slave with a whip when I heard a voice behind me: Understand, Abu Masud; but I did not recognise the voice due to intense anger. He (Abu Mas'ud) reported: As he came near me (I found) that he was the Messenger of Allah (ﷺ) and he was saying: Bear in mind, Abu Mas'ud; bear in mind. Abu Mas'ud. He (Aba Maslad) said: threw the whip from my hand. Thereupon he (the Holy Prophet) said: Bear in mind, Abu Mas'ud; verily Allah has more dominance upon you than you have upon your slave. I (then) said: I would never beat my servant in future}}
\hadithdefcmd{muslim}{4307}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ، - وَهُوَ الْمَعْمَرِيُّ - عَنْ سُفْيَانَ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ، الرَّزَّاقِ أَخْبَرَنَا سُفْيَانُ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا أَبُو عَوَانَةَ، كُلُّهُمْ عَنِ الأَعْمَشِ، بِإِسْنَادِ عَبْدِ الْوَاحِدِ ‏.‏ نَحْوَ حَدِيثِهِ ‏.‏ غَيْرَ أَنَّ فِي حَدِيثِ جَرِيرٍ فَسَقَطَ مِنْ يَدِي السَّوْطُ مِنْ هَيْبَتِهِ ‏.‏\hadithno{4307}\hadithtrans{This hadith has been narrated on the authorityo A'mash but with this variation of words:" There fell from my hand the whip on account of his (the Prophet's) awe}}
\hadithdefcmd{muslim}{4308}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، التَّيْمِيِّ عَنْ أَبِيهِ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ كُنْتُ أَضْرِبُ غُلاَمًا لِي فَسَمِعْتُ مِنْ خَلْفِي صَوْتًا ‏"‏ اعْلَمْ أَبَا مَسْعُودٍ لَلَّهُ أَقْدَرُ عَلَيْكَ مِنْكَ عَلَيْهِ ‏"‏ ‏.‏ فَالْتَفَتُّ فَإِذَا هُوَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ هُوَ حُرٌّ لِوَجْهِ اللَّهِ ‏.‏ فَقَالَ ‏"‏ أَمَا لَوْ لَمْ تَفْعَلْ لَلَفَحَتْكَ النَّارُ أَوْ لَمَسَّتْكَ النَّارُ ‏"‏ ‏.‏\hadithno{4308}\hadithtrans{Abu Mas'ud al-Ansari reported:When I was beating my servant, I heard a voice behind me (saying): Abu Mas'ud, bear in mind Allah has more dominance over you than you have upon him. I turned and (found him) to be Allah's Messenger (ﷺ). I said: Allah's Messenger, I set him free for the sake of Allah. Thereupon he said: Had you not done that, (the gates of) Hell would have opened for you, or the fire would have burnt you}}
\hadithdefcmd{muslim}{4309}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا ابْنُ، أَبِي عَدِيٍّ عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي مَسْعُودٍ، أَنَّهُ كَانَ يَضْرِبُ غُلاَمَهُ فَجَعَلَ يَقُولُ أَعُوذُ بِاللَّهِ - قَالَ - فَجَعَلَ يَضْرِبُهُ فَقَالَ أَعُوذُ بِرَسُولِ اللَّهِ ‏.‏ فَتَرَكَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَاللَّهِ لَلَّهُ أَقْدَرُ عَلَيْكَ مِنْكَ عَلَيْهِ ‏"‏ ‏.‏ قَالَ فَأَعْتَقَهُ ‏.‏\hadithno{4309}\hadithtrans{Abu Mas'ud reported that he had been beating his slave and he had been saying:I seek refuge with Allah, but he continued beating him, whereupon he said: I seek refuge with Allah's Messenger, and he spared him. Thereupon Allah's Messenger (ﷺ) said: By Allah, God has more dominance over you than you have over him (the slave). He said that he set him free}}
\hadithdefcmd{muslim}{4310}{وَحَدَّثَنِيهِ بِشْرُ بْنُ خَالِدٍ، أَخْبَرَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ قَوْلَهُ أَعُوذُ بِاللَّهِ أَعُوذُ بِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4310}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters, but made no mention of (these words) of his:I seek refuge with Allah, I seek refuge with Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{4311}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ نُمَيْرٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ، نُمَيْرٍ حَدَّثَنَا أَبِي، حَدَّثَنَا فُضَيْلُ بْنُ غَزْوَانَ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ أَبِي نُعْمٍ، حَدَّثَنِي أَبُو هُرَيْرَةَ، قَالَ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏ "‏ مَنْ قَذَفَ مَمْلُوكَهُ بِالزِّنَا يُقَامُ عَلَيْهِ الْحَدُّ يَوْمَ الْقِيَامَةِ إِلاَّ أَنْ يَكُونَ كَمَا قَالَ ‏"‏ ‏.‏\hadithno{4311}\hadithtrans{Abu Huraira reported that Abu'l-Qasim (one of the names of Allah's Messenger [may peace be upon him]) said:He who accused his slave of adultery, punishment would be imposed upon him on the Day of Resurrection, except in case the accusation was as he had said}}
\hadithdefcmd{muslim}{4312}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْحَاقُ بْنُ، يُوسُفَ الأَزْرَقُ كِلاَهُمَا عَنْ فُضَيْلِ بْنِ غَزْوَانَ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِي حَدِيثِهِمَا سَمِعْتُ أَبَا، الْقَاسِمِ صلى الله عليه وسلم نَبِيَّ التَّوْبَةِ ‏.‏\hadithno{4312}\hadithtrans{This hadith has been narrated on the authority of Ibn Ghazwan (and the words are):" I heard Abu'l-Qasim (ﷺ) as the Prophet of repentance}}
\hadithdefcmd{muslim}{4313}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنِ الْمَعْرُورِ بْنِ سُوَيْدٍ، قَالَ مَرَرْنَا بِأَبِي ذَرٍّ بِالرَّبَذَةِ وَعَلَيْهِ بُرْدٌ وَعَلَى غُلاَمِهِ مِثْلُهُ فَقُلْنَا يَا أَبَا ذَرٍّ لَوْ جَمَعْتَ بَيْنَهُمَا كَانَتْ حُلَّةً ‏.‏ فَقَالَ إِنَّهُ كَانَ بَيْنِي وَبَيْنَ رَجُلٍ مِنْ إِخْوَانِي كَلاَمٌ وَكَانَتْ أَمُّهُ أَعْجَمِيَّةً فَعَيَّرْتُهُ بِأُمِّهِ فَشَكَانِي إِلَى النَّبِيِّ صلى الله عليه وسلم فَلَقِيتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ يَا أَبَا ذَرٍّ إِنَّكَ امْرُؤٌ فِيكَ جَاهِلِيَّةٌ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ مَنْ سَبَّ الرِّجَالَ سَبُّوا أَبَاهُ وَأُمُّهُ ‏.‏ قَالَ ‏"‏ يَا أَبَا ذَرٍّ إِنَّكَ امْرُؤٌ فِيكَ جَاهِلِيَّةٌ هُمْ إِخْوَانُكُمْ جَعَلَهُمُ اللَّهُ تَحْتَ أَيْدِيكُمْ فَأَطْعِمُوهُمْ مِمَّا تَأْكُلُونَ وَأَلْبِسُوهُمْ مِمَّا تَلْبَسُونَ وَلاَ تُكَلِّفُوهُمْ مَا يَغْلِبُهُمْ فَإِنْ كَلَّفْتُمُوهُمْ فَأَعِينُوهُمْ ‏"‏ ‏.‏\hadithno{4313}\hadithtrans{Al-Ma'rur b. Suwaid said:We went to Abu Dharr (Ghifari) in Rabadha and he had a mantle over him, and his slave had one like it. We said: Abu Dharr, had you joined them together, it would have been a complete garment. Thereupon he said: There was an altercation between me and one of the persons among my brothers. His mother was a non-Arab. I reproached him for his mother. He complained against me to Allah's Apostle (ﷺ). As I met Allah's Apostle (ﷺ) he said: Abu Dharr, you are a person who still has (in him the remnants) of the days (of Ignorance). Thereupon I said: Allah's Messenger, he who abuses (other) persons, they abuse (in return) his father and mother. He (the Holy Prophet) said: Abu Dharr, you are a person who still has (the remnants) of Ignorance in him They (your servants and slaves) are your brothers. Allah has put them in your care, so feed them with what you eat, clothe them with what you wear. and do not burden them beyond their capacities; but if you burden them (with an unbearable burden), then help them (by sharing their extra burden)}}
\hadithdefcmd{muslim}{4314}{وَحَدَّثَنَاهُ أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، كُلُّهُمْ عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ وَزَادَ فِي حَدِيثِ زُهَيْرٍ وَأَبِي مُعَاوِيَةَ بَعْدَ قَوْلِهِ ‏"‏ إِنَّكَ امْرُؤٌ فِيكَ جَاهِلِيَّةٌ ‏"‏ ‏.‏ قَالَ قُلْتُ عَلَى حَالِ سَاعَتِي مِنَ الْكِبَرِ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ وَفِي رِوَايَةِ أَبِي مُعَاوِيَةَ ‏"‏ نَعَمْ عَلَى حَالِ سَاعَتِكَ مِنَ الْكِبَرِ ‏"‏ ‏.‏ وَفِي حَدِيثِ عِيسَى ‏"‏ فَإِنْ كَلَّفَهُ مَا يَغْلِبُهُ فَلْيَبِعْهُ ‏"‏ ‏.‏ وَفِي حَدِيثِ زُهَيْرٍ ‏"‏ فَلْيُعِنْهُ عَلَيْهِ ‏"‏ ‏.‏ وَلَيْسَ فِي حَدِيثِ أَبِي مُعَاوِيَةَ ‏"‏ فَلْيَبِعْهُ ‏"‏ ‏.‏ وَلاَ ‏"‏ فَلْيُعِنْهُ ‏"‏ ‏.‏ انْتَهَى عِنْدَ قَوْلِهِ ‏"‏ وَلاَ يُكَلِّفْهُ مَا يَغْلِبُهُ ‏"‏ ‏.‏\hadithno{4314}\hadithtrans{This hadith has been narrated on the authority of A'mash but with a slight variation of words, e. g. in the hadith transmitted on the authority of Zuhair and Abu Mu'awiya after his words (these words of the Holy Prophet):" You are a person having the remnants of Ignorance in him." (these words also occur, that Abu Dharr) said: Even up to this time of my old age? He (the Holy Prophet) said: Yes. In the tradition transmitted on the authority of Abu Mu'awiya (the words are):" Yes, in this time of your old age." In the tradition transmitted on the authority of 'Isa (the words are):" If you burden him (with an unbearable burden), you should sell him (and get another slave who can easily undertake this burden)." In the hadith transmitted on the authority of Zuhair (the words are):" Help him in that (work)." In the hadith transmitted by Abu Mu'awiya (separately) there is no such word: Then sell him or help him." This hadith concludes with these words:" Do not burden him beyond his capacity}}
\hadithdefcmd{muslim}{4315}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ وَاصِلٍ الأَحْدَبِ، عَنِ الْمَعْرُورِ بْنِ سُوَيْدٍ، قَالَ رَأَيْتُ أَبَا ذَرٍّ وَعَلَيْهِ حُلَّةٌ وَعَلَى غُلاَمِهِ مِثْلُهَا فَسَأَلْتُهُ عَنْ ذَلِكَ قَالَ فَذَكَرَ أَنَّهُ سَابَّ رَجُلاً عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَعَيَّرَهُ بِأُمِّهِ - قَالَ - فَأَتَى الرَّجُلُ النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّكَ امْرُؤٌ فِيكَ جَاهِلِيَّةٌ إِخْوَانُكُمْ وَخَوَلُكُمْ جَعَلَهُمُ اللَّهُ تَحْتَ أَيْدِيكُمْ فَمَنْ كَانَ أَخُوهُ تَحْتَ يَدَيْهِ فَلْيُطْعِمْهُ مِمَّا يَأْكُلُ وَلْيُلْبِسْهُ مِمَّا يَلْبَسُ وَلاَ تُكَلِّفُوهُمْ مَا يَغْلِبُهُمْ فَإِنْ كَلَّفْتُمُوهُمْ فَأَعِينُوهُمْ عَلَيْهِ ‏"‏ ‏.‏\hadithno{4315}\hadithtrans{Ma'rur b. Suwaid reported:I saw Abu Dharr wearing clothes, and his slave wearing similar ones. I asked him about it, and he narrated that he had abused a person during the lifetime of Allah's Messenger (may peace be upoe. him) and he reproached him for his mother. That person came to Allah's Apostle (ﷺ) and made mention of that to him. Thereupon Allah's Apostle (ﷺ) said: You are a person who has (remnants of) Ignorance in him. Your slaves are brothers of yours. Allah has placed them in your hand, and he who has his brother under him, he should feed him with what he eats, and dress him with what he dresses himself, and do not burden them beyond their capacities, and if you burden them, (beyond their capacities), then help them}}
\hadithdefcmd{muslim}{4316}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنَا عَمْرُو، بْنُ الْحَارِثِ أَنَّ بُكَيْرَ بْنَ الأَشَجِّ، حَدَّثَهُ عَنِ الْعَجْلاَنِ، مَوْلَى فَاطِمَةَ عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لِلْمَمْلُوكِ طَعَامُهُ وَكِسْوَتُهُ وَلاَ يُكَلَّفُ مِنَ الْعَمَلِ إِلاَّ مَا يُطِيقُ ‏"‏ ‏.‏\hadithno{4316}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:It is essential to feed the slave, clothe him (properly) and not burden him with work which is beyond his power}}
\hadithdefcmd{muslim}{4317}{وَحَدَّثَنَا الْقَعْنَبِيُّ، حَدَّثَنَا دَاوُدُ بْنُ قَيْسٍ، عَنْ مُوسَى بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا صَنَعَ لأَحَدِكُمْ خَادِمُهُ طَعَامَهُ ثُمَّ جَاءَهُ بِهِ وَقَدْ وَلِيَ حَرَّهُ وَدُخَانَهُ فَلْيُقْعِدْهُ مَعَهُ فَلْيَأْكُلْ فَإِنْ كَانَ الطَّعَامُ مَشْفُوهًا قَلِيلاً فَلْيَضَعْ فِي يَدِهِ مِنْهُ أُكْلَةً أَوْ أُكْلَتَيْنِ ‏"‏ ‏.‏ قَالَ دَاوُدُ يَعْنِي لُقْمَةً أَوْ لُقْمَتَيْنِ ‏.‏\hadithno{4317}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:When the slave of anyone amongst you prepares food for him and he serves him after having sat close to (and undergoing the hardship of) heat and smoke, he should make him (the slave) sit along with him and make him eat (along with him), and if the food seems to run short, then he should spare some portion for him (from his own share) - (another narrator) Dawud said:" i. e. a morsel or two}}
\hadithdefcmd{muslim}{4318}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْعَبْدَ إِذَا نَصَحَ لِسَيِّدِهِ وَأَحْسَنَ عِبَادَةَ اللَّهِ فَلَهُ أَجْرُهُ مَرَّتَيْنِ ‏"‏ ‏.‏\hadithno{4318}\hadithtrans{Ibn Umar reported Allah's Messenger (ﷺ) as saying:When a slave looks to the welfare of his master and worships Allah well, he has two rewards for him}}
\hadithdefcmd{muslim}{4319}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى، وَهْوَ الْقَطَّانُ ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ كُلُّهُمْ عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي أُسَامَةُ، جَمِيعًا عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ مَالِكٍ ‏.‏\hadithno{4319}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Umar through another chain of transmitters}}
\hadithdefcmd{muslim}{4320}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ قَالَ أَبُو هُرَيْرَةَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لِلْعَبْدِ الْمَمْلُوكِ الْمُصْلِحِ أَجْرَانِ ‏"‏ ‏.‏ وَالَّذِي نَفْسُ أَبِي هُرَيْرَةَ بِيَدِهِ لَوْلاَ الْجِهَادُ فِي سَبِيلِ اللَّهِ وَالْحَجُّ وَبِرُّ أُمِّي لأَحْبَبْتُ أَنْ أَمُوتَ وَأَنَا مَمْلُوكٌ ‏.‏ قَالَ وَبَلَغَنَا أَنَّ أَبَا هُرَيْرَةَ لَمْ يَكُنْ يَحُجُّ حَتَّى مَاتَتْ أُمُّهُ لِصُحْبَتِهَا ‏.‏ قَالَ أَبُو الطَّاهِرِ فِي حَدِيثِهِ ‏"‏ لِلْعَبْدِ الْمُصْلِحِ ‏"‏ ‏.‏ وَلَمْ يَذْكُرِ الْمَمْلُوكَ ‏.‏\hadithno{4320}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:For a faithful slave there are two rewards. By him in Whose hand is the life of Abu Huraira, but for Jihad in the cause of Allah, and Pilgrimage and kindness to my mother, I would have preferred to die as a slave. He (one of the narrators in the chain of transmitters) said: This news reached us that Abu Huraira did not perform Pilgrimage until his mother died for (keeping himself constantly) in her service}}
\hadithdefcmd{muslim}{4321}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا أَبُو صَفْوَانَ الأُمَوِيُّ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ بَلَغَنَا وَمَا بَعْدَهُ ‏.‏\hadithno{4321}\hadithtrans{This hadith has been transmitted on the authority of Abu Tahir but with a slight variation of words}}
\hadithdefcmd{muslim}{4322}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَدَّى الْعَبْدُ حَقَّ اللَّهِ وَحَقَّ مَوَالِيهِ كَانَ لَهُ أَجْرَانِ ‏"‏ ‏.‏ قَالَ فَحَدَّثْتُهَا كَعْبًا فَقَالَ كَعْبٌ لَيْسَ عَلَيْهِ حِسَابٌ وَلاَ عَلَى مُؤْمِنٍ مُزْهِدٍ ‏.‏\hadithno{4322}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:When a slave fulfils obligation of Allah and obligation of his master, he has two rewards for him. I narrated this to Ka'b, and Ka'b said: (Such a slave) has no accountability, nor has a poor believer}}
\hadithdefcmd{muslim}{4323}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{4323}\hadithtrans{The above hadith has been reported through another chain of transmitters on the authority of Abu Huraira}}
\hadithdefcmd{muslim}{4324}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نِعِمَّا لِلْمَمْلُوكِ أَنْ يُتَوَفَّى يُحْسِنُ عِبَادَةَ اللَّهِ وَصَحَابَةَ سَيِّدِهِ نِعِمَّا لَهُ ‏"‏ ‏.‏\hadithno{4324}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:It is good for a slave that he worships Allah well, and serves his master (well). It is good for him}}
\hadithdefcmd{muslim}{4325}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قُلْتُ لِمَالِكٍ حَدَّثَكَ نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَعْتَقَ شِرْكًا لَهُ فِي عَبْدٍ فَكَانَ لَهُ مَالٌ يَبْلُغُ ثَمَنَ الْعَبْدِ قُوِّمَ عَلَيْهِ قِيمَةَ الْعَدْلِ فَأَعْطَى شُرَكَاءَهُ حِصَصَهُمْ وَعَتَقَ عَلَيْهِ الْعَبْدُ وَإِلاَّ فَقَدْ عَتَقَ مِنْهُ مَا عَتَقَ ‏"‏ ‏.‏\hadithno{4325}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) as saying:He who gives up his share in a slave, and has enough money to pay the full price of the slave, then full emancipation devolves upon him; but if he has not the money, then he emancipated what he emancipated}}
\hadithdefcmd{muslim}{4326}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَعْتَقَ شِرْكًا لَهُ مِنْ مَمْلُوكٍ فَعَلَيْهِ عِتْقُهُ كُلُّهُ إِنْ كَانَ لَهُ مَالٌ يَبْلُغُ ثَمَنَهُ فَإِنْ لَمْ يَكُنْ لَهُ مَالٌ عَتَقَ مِنْهُ مَا عَتَقَ ‏"‏ ‏.‏\hadithno{4326}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) as saying:He who emancipates his share in the slave, it is his responsibility to secure full freedom for him provided he (the slave) has enough money to pay the (remaining) price, but it he has not so much money he would be emancipated to the extent that the first man emancipated}}
\hadithdefcmd{muslim}{4327}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ نَافِعٍ، مَوْلَى عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَعْتَقَ نَصِيبًا لَهُ فِي عَبْدٍ فَكَانَ لَهُ مِنَ الْمَالِ قَدْرُ مَا يَبْلُغُ قِيمَتَهُ قُوِّمَ عَلَيْهِ قِيمَةَ عَدْلٍ وَإِلاَّ فَقَدْ عَتَقَ مِنْهُ مَا عَتَقَ ‏"‏ ‏.‏\hadithno{4327}\hadithtrans{Abdullah b. 'Umar reported Allah's Messenger (ﷺ) as saying:He who gives up his share in a slave, and he has money enough to meet the full price, a fair price for him should be fixed; otherwise be has emancipated him to the extent that he has emancipated}}
\hadithdefcmd{muslim}{4328}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ رُمْحٍ، عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنَا مُحَمَّدُ، بْنُ الْمُثَنَّى حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، ح وَحَدَّثَنِي أَبُو الرَّبِيعِ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادٌ، وَهُوَ ابْنُ زَيْدٍ ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - كِلاَهُمَا عَنْ أَيُّوبَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي إِسْمَاعِيلُ بْنُ أُمَيَّةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ ابْنِ أَبِي ذِئْبٍ، ح وَحَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي أُسَامَةُ، - يَعْنِي ابْنَ زَيْدٍ - كُلُّ هَؤُلاَءِ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ وَلَيْسَ فِي حَدِيثِهِمْ ‏ "‏ وَإِنْ لَمْ يَكُنْ لَهُ مَالٌ فَقَدْ عَتَقَ مِنْهُ مَا عَتَقَ ‏"‏ ‏.‏ إِلاَّ فِي حَدِيثِ أَيُّوبَ وَيَحْيَى بْنِ سَعِيدٍ فَإِنَّهُمَا ذَكَرَا هَذَا الْحَرْفَ فِي الْحَدِيثِ وَقَالاَ لاَ نَدْرِي أَهُوَ شَىْءٌ فِي الْحَدِيثِ أَوْ قَالَهُ نَافِعٌ مِنْ قِبَلِهِ وَلَيْسَ فِي رِوَايَةِ أَحَدٍ مِنْهُمْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ إِلاَّ فِي حَدِيثِ اللَّيْثِ بْنِ سَعْدٍ ‏.‏\hadithno{4328}\hadithtrans{This hadith has been narrated through another chain of transmitters with a slight variation of words}}
\hadithdefcmd{muslim}{4329}{وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، كِلاَهُمَا عَنِ ابْنِ عُيَيْنَةَ، قَالَ ابْنُ أَبِي عُمَرَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ عَبْدًا بَيْنَهُ وَبَيْنَ آخَرَ قُوِّمَ عَلَيْهِ فِي مَالِهِ قِيمَةَ عَدْلٍ لاَ وَكْسَ وَلاَ شَطَطَ ثُمَّ عَتَقَ عَلَيْهِ فِي مَالِهِ إِنْ كَانَ مُوسِرًا ‏"‏ ‏.‏\hadithno{4329}\hadithtrans{Salim b. 'Abdullah reported on the authority of his father that Allah's Apostle (ﷺ) said:He who emancipates a slave (shared) by him and another one, his full price may be justly assessed from his wealth, neither less nor more, and he (the slave) would be emancipated if he (the partner) would be solvent enough (to forgo the amount of his share)}}
\hadithdefcmd{muslim}{4330}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ شِرْكًا لَهُ فِي عَبْدٍ عَتَقَ مَا بَقِيَ فِي مَالِهِ إِذَا كَانَ لَهُ مَالٌ يَبْلُغُ ثَمَنَ الْعَبْدِ ‏"‏ ‏.‏\hadithno{4330}\hadithtrans{Ibn 'Umar reported Allah's Apostle (ﷺ) as saying:He who gives up his share in a slave, the remaining (share) will be paid out of his riches if his riches are enough to meet the price of the slave}}
\hadithdefcmd{muslim}{4331}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي، هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ فِي الْمَمْلُوكِ بَيْنَ الرَّجُلَيْنِ فَيُعْتِقُ أَحَدُهُمَا قَالَ ‏ "‏ يَضْمَنُ ‏"‏ ‏.‏\hadithno{4331}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:In case the slave is owned by two persons, and one of them emancipates him, he will guarantee (his full freedom)}}
\hadithdefcmd{muslim}{4332}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ قَالَ ‏ "‏ مَنْ أَعْتَقَ شَقِيصًا مِنْ مَمْلُوكٍ فَهُوَ حُرٌّ مِنْ مَالِهِ ‏"‏ ‏.‏\hadithno{4332}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters (and the words are):" He who emancipates a portion in a slave, he should (secure full) freedom for him from his property}}
\hadithdefcmd{muslim}{4333}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ شَقِيصًا لَهُ فِي عَبْدٍ فَخَلاَصُهُ فِي مَالِهِ إِنْ كَانَ لَهُ مَالٌ فَإِنْ لَمْ يَكُنْ لَهُ مَالٌ اسْتُسْعِيَ الْعَبْدُ غَيْرَ مَشْقُوقٍ عَلَيْهِ ‏"‏ ‏.‏\hadithno{4333}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:He who emancipates his portion in a slave, full emancipation may be secured for him out of his property (if he has money) if he has enough property to meet (the required expenses), but if he has not enough property, the slave should be put to extra labour (in order to earn money for buying his freedom), but he should not be overburdened}}
\hadithdefcmd{muslim}{4334}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، وَمُحَمَّدُ بْنُ بِشْرٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ خَشْرَمٍ، قَالاَ أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، جَمِيعًا عَنِ ابْنِ أَبِي، عَرُوبَةَ بِهَذَا الإِسْنَادِ ‏.‏ وَفِي حَدِيثِ عِيسَى ‏ "‏ ثُمَّ يُسْتَسْعَى فِي نَصِيبِ الَّذِي لَمْ يُعْتِقْ غَيْرَ مَشْقُوقٍ عَلَيْهِ ‏"‏ ‏.‏\hadithno{4334}\hadithtrans{This hadith has been narrated through another chain of transmitters (and the words are):" He will be required to work (in order to secure freedom) for that por- tion in which he has not been emancipated, without overburdening him}}
\hadithdefcmd{muslim}{4335}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ عُلَيَّةَ - عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ، بْنِ حُصَيْنٍ ‏.‏ أَنَّ رَجُلاً، أَعْتَقَ سِتَّةَ مَمْلُوكِينَ لَهُ عِنْدَ مَوْتِهِ لَمْ يَكُنْ لَهُ مَالٌ غَيْرُهُمْ فَدَعَا بِهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَزَّأَهُمْ أَثْلاَثًا ثُمَّ أَقْرَعَ بَيْنَهُمْ فَأَعْتَقَ اثْنَيْنِ وَأَرَقَّ أَرْبَعَةً وَقَالَ لَهُ قَوْلاً شَدِيدًا ‏.‏\hadithno{4335}\hadithtrans{Imran b. Husain reported that a person who had no other property emancipated six slaves of his at the time of his death. Allah's Messenger (ﷺ) called for them and divided them into three sections, cast lots amongst them, and set two free and kept four in slavery; and he (the Holy Prophet) spoke severely of him}}
\hadithdefcmd{muslim}{4336}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي، عُمَرَ عَنِ الثَّقَفِيِّ، كِلاَهُمَا عَنْ أَيُّوبَ، بِهَذَا الإِسْنَادِ ‏.‏ أَمَّا حَمَّادٌ فَحَدِيثُهُ كَرِوَايَةِ ابْنِ عُلَيَّةَ وَأَمَّا الثَّقَفِيُّ فَفِي حَدِيثِهِ أَنَّ رَجُلاً مِنَ الأَنْصَارِ أَوْصَى عِنْدَ مَوْتِهِ فَأَعْتَقَ سِتَّةَ مَمْلُوكِينَ ‏.‏\hadithno{4336}\hadithtrans{This hadith has been narrated through another chain of transmitters (and the words are):" A person from among the Ansar willed away the freedom of six slaves of his at the time of his death}}
\hadithdefcmd{muslim}{4337}{وَحَدَّثَنَا مُحَمَّدُ بْنُ مِنْهَالٍ الضَّرِيرُ، وَأَحْمَدُ بْنُ عَبْدَةَ، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ ابْنِ عُلَيَّةَ وَحَمَّادٍ ‏.‏\hadithno{4337}\hadithtrans{This hadith has been reported on the authority of Imran b. Husain through another chain of narrators}}
\hadithdefcmd{muslim}{4338}{حَدَّثَنَا أَبُو الرَّبِيعِ، سُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ أَعْتَقَ غُلاَمًا لَهُ عَنْ دُبُرٍ لَمْ يَكُنْ لَهُ مَالٌ غَيْرُهُ فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ مَنْ يَشْتَرِيهِ مِنِّي ‏"‏ ‏.‏ فَاشْتَرَاهُ نُعَيْمُ بْنُ عَبْدِ اللَّهِ بِثَمَانِمِائَةِ دِرْهَمٍ فَدَفَعَهَا إِلَيْهِ ‏.‏ قَالَ عَمْرٌو سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ يَقُولُ عَبْدًا قِبْطِيًّا مَاتَ عَامَ أَوَّلَ ‏.‏\hadithno{4338}\hadithtrans{Jabir b. 'Abdullah said that a person among the Ansar declared his slave free after his death, as he had no other property. This news reached the Messenger of Allah (ﷺ) and he said:Who will buy him from me? And Nu'aim b. al-Nahham bought him for eight hundred dirhams and he handed them over to him, 'Amr (one of the narrators) said: I heard Jabir b. 'Abdullah as saying: He was a Coptic slave, and he died in the first year (of the Caliphate of 'Abdullah b. Zubair)}}
\hadithdefcmd{muslim}{4339}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنِ ابْنِ عُيَيْنَةَ، قَالَ أَبُو بَكْرٍ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، قَالَ سَمِعَ عَمْرٌو، جَابِرًا يَقُولُ دَبَّرَ رَجُلٌ مِنَ الأَنْصَارِ غُلاَمًا لَهُ لَمْ يَكُنْ لَهُ مَالٌ غَيْرُهُ فَبَاعَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ جَابِرٌ فَاشْتَرَاهُ ابْنُ النَّحَّامِ عَبْدًا قِبْطِيًّا مَاتَ عَامَ أَوَّلَ فِي إِمَارَةِ ابْنِ الزُّبَيْرِ ‏.‏\hadithno{4339}\hadithtrans{Jabir is reported to have said:A person amongst the Ansar who had no other property declared a slave free after his death. Allah's Messenger (ﷺ) sold him, and Ibn al-Nahham bought him and he was a Coptic slave (who) died in the first year of the Caliphate of Ibn Zubair}}
\hadithdefcmd{muslim}{4340}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَابْنُ، رُمْحٍ عَنِ اللَّيْثِ بْنِ سَعْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الْمُدَبَّرِ نَحْوَ حَدِيثِ حَمَّادٍ عَنْ عَمْرِو بْنِ دِينَارٍ ‏.‏\hadithno{4340}\hadithtrans{A hadith like this has been narrated on the authority of Jabir through another chain of transmitters}}
\hadithdefcmd{muslim}{4341}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ، - يَعْنِي الْحِزَامِيَّ - عَنْ عَبْدِ الْمَجِيدِ بْنِ، سُهَيْلٍ عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، ح. وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ هَاشِمٍ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ - عَنِ الْحُسَيْنِ بْنِ، ذَكْوَانَ الْمُعَلِّمِ حَدَّثَنِي عَطَاءٌ، عَنْ جَابِرٍ، ح. وَحَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، حَدَّثَنَا مُعَاذٌ، حَدَّثَنِي أَبِي، عَنْ مَطَرٍ، عَنْ عَطَاءِ بْنِ، أَبِي رَبَاحٍ وَأَبِي الزُّبَيْرِ وَعَمْرِو بْنِ دِينَارٍ أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ، حَدَّثَهُمْ فِي، بَيْعِ الْمُدَبَّرِ ‏.‏ كُلُّ هَؤُلاَءِ قَالَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ حَمَّادٍ وَابْنِ عُيَيْنَةَ عَنْ عَمْرٍو عَنْ جَابِرٍ ‏.‏\hadithno{4341}\hadithtrans{This hadith has been narrated from Allah's Messenger (ﷺ) through other chains of transmitters}}
